# Generated by roxygen2: do not edit by hand

S3method(as_dist_structure,dist)
S3method(as_dist_structure,dist_structure)
S3method(birnbaum_importance,dist_structure)
S3method(cdf,cold_standby_dist)
S3method(cdf,dist_structure)
S3method(component,coherent_dist)
S3method(component,cold_standby_dist)
S3method(component,dual_of_system)
S3method(compose_systems,dist_structure)
S3method(critical_states,dist_structure)
S3method(criticality_importance,dist_structure)
S3method(density,exp_kofn)
S3method(density,exp_series)
S3method(density,wei_kofn)
S3method(dual,coherent_dist)
S3method(dual,dist_structure)
S3method(dual,dual_of_system)
S3method(format,dist_structure)
S3method(hazard,exp_kofn)
S3method(hazard,exp_series)
S3method(hazard,wei_kofn)
S3method(hazard,wei_series)
S3method(is_coherent,dist_structure)
S3method(mean,cold_standby_dist)
S3method(mean,exp_parallel)
S3method(mean,exp_series)
S3method(mean,wei_homogeneous_series)
S3method(min_cuts,dist_structure)
S3method(min_paths,coherent_dist)
S3method(min_paths,dist_structure)
S3method(min_paths,parallel_dist)
S3method(min_paths,series_dist)
S3method(ncomponents,coherent_dist)
S3method(ncomponents,cold_standby_dist)
S3method(ncomponents,dual_of_system)
S3method(phi,dist_structure)
S3method(phi,dual_of_system)
S3method(phi,kofn_dist)
S3method(phi,parallel_dist)
S3method(phi,series_dist)
S3method(print,dist_structure)
S3method(reliability,dist_structure)
S3method(sampler,cold_standby_dist)
S3method(sampler,dist_structure)
S3method(sampler,exp_kofn)
S3method(sampler,exp_parallel)
S3method(sampler,exp_series)
S3method(sampler,gamma_series)
S3method(sampler,lognormal_series)
S3method(sampler,wei_homogeneous_series)
S3method(sampler,wei_kofn)
S3method(sampler,wei_series)
S3method(structural_importance,dist_structure)
S3method(substitute_component,dist_structure)
S3method(surv,cold_standby_dist)
S3method(surv,dist_structure)
S3method(surv,exp_kofn)
S3method(surv,exp_parallel)
S3method(surv,exp_series)
S3method(surv,gamma_series)
S3method(surv,lognormal_series)
S3method(surv,parallel_dist)
S3method(surv,series_dist)
S3method(surv,wei_homogeneous_series)
S3method(surv,wei_kofn)
S3method(surv,wei_series)
S3method(system_censoring,dist_structure)
S3method(system_lifetime,dist_structure)
S3method(system_signature,dist_structure)
S3method(vesely_fussell_importance,dist_structure)
export(as_dist_structure)
export(birnbaum_importance)
export(bridge_dist)
export(coherent_dist)
export(cold_standby_dist)
export(component)
export(compose_systems)
export(consecutive_k_dist)
export(critical_states)
export(criticality_importance)
export(dual)
export(exp_kofn)
export(exp_parallel)
export(exp_series)
export(gamma_series)
export(is_coherent)
export(is_dist_structure)
export(kofn_dist)
export(lognormal_series)
export(max_iid)
export(min_cuts)
export(min_iid)
export(min_paths)
export(ncomponents)
export(order_statistic)
export(parallel_dist)
export(phi)
export(reliability)
export(series_dist)
export(structural_importance)
export(substitute_component)
export(system_censoring)
export(system_lifetime)
export(system_signature)
export(validate_dist_structure)
export(vesely_fussell_importance)
export(wei_homogeneous_series)
export(wei_kofn)
export(wei_series)
importFrom(algebraic.dist,cdf)
importFrom(algebraic.dist,hazard)
importFrom(algebraic.dist,sampler)
importFrom(algebraic.dist,surv)
importFrom(stats,density)
importFrom(stats,dexp)
importFrom(stats,dweibull)
