% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/coercions.R, R/generics.R
\name{as_dist_structure.dist_structure}
\alias{as_dist_structure.dist_structure}
\alias{as_dist_structure.dist}
\alias{as_dist_structure}
\title{Coerce to dist_structure}
\usage{
\method{as_dist_structure}{dist_structure}(x, ...)

\method{as_dist_structure}{dist}(x, ...)

as_dist_structure(x, ...)
}
\arguments{
\item{x}{A dist or dist_structure.}

\item{...}{Reserved for methods.}
}
\value{
A \link{dist_structure} object.
}
\description{
Wraps a plain \code{algebraic.dist} distribution in a 1-component \link{series_dist}
so that it satisfies the dist_structure protocol. Useful for
polymorphic code that operates on dist_structure inputs but is also
handed unwrapped distributions. A \code{dist_structure} is returned
unchanged.
}
