% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/coherent_dist.R
\name{consecutive_k_dist}
\alias{consecutive_k_dist}
\title{Consecutive-k-out-of-n system distribution (type G)}
\usage{
consecutive_k_dist(k, components)
}
\arguments{
\item{k}{Block size.}

\item{components}{List of \code{dist} objects (length \code{n}).}
}
\value{
A \code{consecutive_k_dist} inheriting from \code{coherent_dist}.
}
\description{
The consecutive-k-out-of-n:G system functions when at least one block
of \code{k} consecutive components all function. Minimal path sets are the
\code{n - k + 1} consecutive blocks of size \code{k}. (Note: this is the :G
variant; the :F variant, "fails when any \code{k} consecutive fail", has
different minimal paths.)
}
