% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/generics.R, R/importance.R
\name{birnbaum_importance}
\alias{birnbaum_importance}
\alias{birnbaum_importance.dist_structure}
\title{Birnbaum reliability importance}
\usage{
birnbaum_importance(x, j, p)

\method{birnbaum_importance}{dist_structure}(x, j, p)
}
\arguments{
\item{x}{A \link{dist_structure} object.}

\item{j}{Component index.}

\item{p}{Numeric vector of length \code{ncomponents(x)} or a scalar in
\verb{[0, 1]}.}
}
\value{
Numeric scalar in \verb{[0, 1]}.
}
\description{
The Birnbaum importance of component \code{j} at component reliabilities
\code{p} is \verb{dR/dp_j = R(p with p_j = 1) - R(p with p_j = 0)}. Measures
how much the system reliability changes if \code{j} moves between certain
failure and certain success (and, by monotonicity, the rate of
change at any intermediate \code{p_j}).
}
