% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/defaults.R, R/generics.R
\name{min_paths.dist_structure}
\alias{min_paths.dist_structure}
\alias{min_paths}
\title{Minimal path sets}
\usage{
\method{min_paths}{dist_structure}(x)

min_paths(x)
}
\arguments{
\item{x}{A \link{dist_structure} object.}
}
\value{
A list of integer vectors.
}
\description{
Returns the minimal subsets of \code{1:m} whose joint functioning is
sufficient for the system to function. \code{min_paths} and \code{\link[=phi]{phi()}} are
dual primitives in the \code{dist_structure} protocol: providing one is
enough, the other has an enumerative default.
}
\seealso{
\code{\link[=phi]{phi()}} for the dual primitive; \code{\link[=min_cuts]{min_cuts()}} for the dual
topology query (minimal subsets whose joint failure causes system
failure).
}
